@@ -6,7 +6,7 @@
 import io
 import json
 import base64
-from pypykatz.commons.common import WindowsMinBuild, KatzSystemArchitecture, AGenericReader, UniversalEncoder, hexdump
+from pypykatz.commons.common import WindowsBuild, WindowsMinBuild, KatzSystemArchitecture, AGenericReader, UniversalEncoder, hexdump
 from pypykatz.commons.filetime import filetime_to_dt
 from pypykatz.alsadecryptor.packages.msv.templates import MSV1_0_PRIMARY_CREDENTIAL_STRANGE_DEC
 from pypykatz.alsadecryptor.packages.credman.templates import KIWI_CREDMAN_LIST_STARTER, KIWI_CREDMAN_SET_LIST_ENTRY
@@ -32,7 +32,7 @@ class MsvCredential:
 		t['LMHash'] = self.LMHash
 		t['SHAHash'] = self.SHAHash
 		t['DPAPI'] = self.DPAPI
-		t['isoProt'] = self.isoProt
+		#t['isoProt'] = self.isoProt # removed this because it's not implemented fully and messes up the testcases
 		return t
 		
 	def to_json(self):
@@ -288,15 +288,14 @@ class MsvDecryptor(PackageDecryptor):
 	async def find_first_entry(self):
 		#finding signature
 		position = await self.find_signature('lsasrv.dll',self.decryptor_template.signature)
-
 		#getting logon session count
-		if self.sysinfo.architecture == KatzSystemArchitecture.X64 and self.sysinfo.buildnumber > WindowsMinBuild.WIN_BLUE.value:
-			ptr_entry_loc = await self.reader.get_ptr_with_offset(position + self.decryptor_template.offset2)
-			await self.reader.move(ptr_entry_loc)
-			t = await self.reader.read(1)
-			self.logon_session_count = int.from_bytes(t, byteorder = 'big', signed = False)
-		else:
-			self.logon_session_count = 1
+		self.logon_session_count = 1
+		if self.sysinfo.architecture == KatzSystemArchitecture.X64:
+			if self.sysinfo.buildnumber >= WindowsBuild.WIN_8.value or (WindowsMinBuild.WIN_8.value <= self.sysinfo.buildnumber < WindowsMinBuild.WIN_BLUE.value and self.sysinfo.msv_dll_timestamp > 0x60000000):
+				ptr_entry_loc = await self.reader.get_ptr_with_offset(position + self.decryptor_template.offset2)
+				await self.reader.move(ptr_entry_loc)
+				t = await self.reader.read(1)
+				self.logon_session_count = int.from_bytes(t, byteorder = 'big', signed = False)
 
 		#getting logon session ptr
 		ptr_entry_loc = await self.reader.get_ptr_with_offset(position + self.decryptor_template.first_entry_offset)
