@@ -360,6 +360,7 @@ class WindowsBuild(enum.Enum):
 	WIN_10_2004 = 19041
 	WIN_10_20H2 = 19042
 	WIN_11_2022 = 20348
+	WIN_11_2023 = 22621
 	
 class WindowsMinBuild(enum.Enum):
 	WIN_XP = 2500
@@ -456,7 +457,7 @@ class KatzSystemInfo:
 		self.major_version = 6
 		
 	def __str__(self):
-		return '%s %s' % (self.architecture.name, self.buildnumber)
+		return 'ARCH:%s BUILD:%s MSV_TS:%s OS(guess): %s' % (self.architecture.name, self.buildnumber, self.msv_dll_timestamp, self.operating_system)
 	
 	@staticmethod
 	def from_live_reader(lr):
