@@ -3,19 +3,15 @@
 # Author:
 #  Tamas Jos (@skelsec)
 #
-import hashlib
-import hmac
-from pypykatz.registry.sam.structures import *
-from pypykatz.crypto.RC4 import RC4
-from pypykatz.crypto.aes import AESModeOfOperationCBC,AESModeOfOperationECB, Decrypter
-from pypykatz.crypto.des import *
-
+from unicrypto import hashlib
+from unicrypto import hmac
+from unicrypto.symmetric import RC4, AES, MODE_CBC, DES, expand_DES_key
 
 #####
-from pypykatz.registry.security.structures import *
-from pypykatz.registry.security.common import *
+import io
+from pypykatz.registry.security.structures import LSA_SECRET, LSA_SECRET_BLOB, LSA_SECRET_XP, NL_RECORD
+from pypykatz.registry.security.common import LSADCCSecret, LSASecret
 from pypykatz.registry import logger
-from pypykatz.commons.common import hexdump
 
 #
 # The SECURITY hive holds all the domain-cached-credentials for the domain users who logged in to the machine
@@ -25,8 +21,9 @@ from pypykatz.commons.common import hexdump
 # as this functionality can be used by any service that wants to stroe some secret information
 
 class SECURITY:
-	def __init__(self, security_hive, bootkey):
+	def __init__(self, security_hive, bootkey, system_hive = None):
 		self.hive = security_hive
+		self.system_hive = system_hive
 		self.bootkey = bootkey
 		
 		self.dcc_iteration_count = 10240
@@ -51,7 +48,7 @@ class SECURITY:
 			record = LSA_SECRET.from_bytes(data)
 			key = SECURITY.sha256_multi(self.bootkey, record.data[:32])
 			secret_dec = b''
-			cipher = AESModeOfOperationECB(key)
+			cipher = AES(key)
 			n = 16
 			for block in [record.data[32:][i:i+n] for i in range(0, len(record.data[32:]), n)]:  #terrible, terrible workaround
 				if len(block) < n:
@@ -96,7 +93,7 @@ class SECURITY:
 		for _ in range(0, len(value), 8):
 			enc_blob = value[:8]
 			des_key = expand_DES_key(t_key[:7])
-			ctx = des(des_key)
+			ctx = DES(des_key)
 			dec_blob += ctx.decrypt(enc_blob)
 			t_key = t_key[7:]
 			value = value[8:]
@@ -120,7 +117,7 @@ class SECURITY:
 			self.NKLM_key = b''
 			record = LSA_SECRET.from_bytes(value[1])
 			key = SECURITY.sha256_multi(self.lsa_key, record.data[:32])
-			cipher = AESModeOfOperationECB(key)
+			cipher = AES(key)
 			n = 16
 			for block in [record.data[32:][i:i+n] for i in range(0, len(record.data[32:]), n)]:  #terrible, terrible workaround
 				if len(block) < n:
@@ -177,7 +174,7 @@ class SECURITY:
 					# Encrypted
 					if self.lsa_secret_key_vista_type is True:
 						plaintext = b''
-						cipher = AESModeOfOperationCBC(self.NKLM_key[16:32], iv = record.IV)
+						cipher = AES(self.NKLM_key[16:32], MODE_CBC, IV = record.IV)
 						n = 16
 						for block in [record.EncryptedData[i:i+n] for i in range(0, len(record.EncryptedData), n)]:  #terrible, terrible workaround
 							if len(block) < 16:
@@ -185,7 +182,7 @@ class SECURITY:
 							plaintext += cipher.decrypt(block)
 							
 					else:
-						key = hmac.new(self.NKLM_key,record.IV).digest()
+						key = hmac.new(self.NKLM_key,record.IV, digestmod='md5').digest()
 						cipher = RC4(key)
 						plaintext = cipher.decrypt(record.EncryptedData)
 						
@@ -234,7 +231,7 @@ class SECURITY:
 						record = LSA_SECRET.from_bytes(v[1])
 						key = SECURITY.sha256_multi(self.lsa_key, record.data[:32])
 						secret_dec = b''
-						cipher = AESModeOfOperationECB(key)
+						cipher = AES(key)
 						n = 16
 						for block in [record.data[32:][i:i+n] for i in range(0, len(record.data[32:]), n)]:  #terrible, terrible workaround
 							if len(block) < n:
@@ -246,7 +243,7 @@ class SECURITY:
 					else:
 						dec_blob = self.decrypt_secret(self.lsa_key, v[1])
 						
-					secret = LSASecret.process(key_name, dec_blob, vl == 'OldVal')
+					secret = LSASecret.process(key_name, dec_blob, vl == 'OldVal', self.system_hive)
 					if secret is not None:
 						self.cached_secrets.append(secret)
 					
